/* version.c (version information) */

/***********************************************************************
*  This code is part of Statistics for MySQL.
*
*  Copyright (C) 2011 Heinrich Schuchardt (xypron.glpk@gmx.de)
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
***********************************************************************/

#include <stdlib.h>
#include <stdio.h>
#include <time.h>
#include "config.h"
#include "sqlstat.h"

#define BUFLEN 128

int main(int argc, char *argv[]) {
#ifdef SQLWIN
  char *filename = "..\\doc\\version.html";
#else
  char *filename = "../doc/version.html";
#endif
  FILE *file;
  time_t rawtime;
  struct tm *now;
  char buf[BUFLEN];
  char *header =
    "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\""
    " \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n"
    "<html xmlns=\"http://www.w3.org/1999/xhtml\">\n"
    "<head>\n"
    "<meta http-equiv=\"content-type\" content=\"text/html; charset=iso-8859-1"
    "\" />\n"
    "<meta  name=\"keywords\" content=\"Statistics for MySQL, version\" />\n"
    "<title>Statistics for MySQL</title>\n"
    "<link rel=\"stylesheet\" type=\"text/css\" href=\"css/default.css\" />\n"
    "<link rel=\"icon\" href=\"/images/favicon.png\" type=\"image/png\" />\n"
    "</head>\n"
    "<body id=\"body\">\n"
    "<div id=\"container\">\n"
    "  <div id=\"header\">\n"
    "    <div id=\"logo\">\n"
    "    <img src=\"images/xypron100.png\" width=\"148\" height=\"100\" alt=\""
    "Logo\" />\n"
    "    Statistics for MySQL\n"
    "    </div>\n"
    "    <div id=\"nav\">\n"
    "	<a href=\"http://www.xypron.de\">Xypron</a> &gt;\n"
    "	<a href=\"http://www.xypron.de/projects\">Projects</a> &gt;\n"
    "    <a href=\"index.html\">Statistics for MySQL</a> &gt; Version\n"
    "    </div>\n"
    "  </div>\n"
    "  <div id=\"main\">\n"
    "    <h1>Version Information</h1>\n";
  char *footer1 =
    "  </div>\n"
    "  <div id=\"links\">\n"
    "    <h5>Overview</h5>\n"
    "    <ul>\n"
    "    <li><a href=\"index.html\">About</a><br/></li>\n"
    "    <li><b><a href=\"version.html\">Version</a></b></li>\n"
    "    </ul>\n"
    "    <h5>Documentation</h5>\n"
    "    <ul>\n"
    "    <li><a href=\"doxygen/html/index.html\">Doxygen</a></li>\n"
    "    </ul>\n"
    "  </div>\n"
    "  <div id=\"footer\">\n"
    "  <a href=\"http://sourceforge.net/projects/sqlstat\"><img\n"
    "  src=\"http://sflogo.sourceforge.net/sflogo.php?group_id=576324&amp;type"
    "=8\"\n"
    "  width=\"80\" height=\"15\" alt=\"Get Statistics for MySQL at SourceForg"
    "e.net. Fast, secure and Free Open Source software downloads\"\n"
    "  /></a>\n"
    "  Xypron, ";
  char *footer2 =
    "</div>\n"
    "</div>\n"
    "</body></html>";
    
  file = fopen(filename, "w");
  if (file == NULL) {
    return EXIT_FAILURE;
  }
  
  fprintf(file, "%s\n", header);
  fprintf(file, "    <p>libsqlstat version: %s<br />\n", VERSION);
  fprintf(file, "    MySQL server version: %s</p>\n", MYSQL_SERVER_VERSION); 
  time(&rawtime);
  now = localtime( &rawtime );
  strftime(buf, BUFLEN, "%Y-%m-%d", now);
  fprintf(file, "%s%s%s\n", footer1, buf, footer2);
  fclose(file);
  return EXIT_SUCCESS;
}
