/* sqlplugin.cc (plugin) */

/***********************************************************************
*  This code is part of Statistics for MySQL.
*
*  Copyright (C) 2011 Heinrich Schuchardt (xypron.glpk@gmx.de)
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
***********************************************************************/

/**
 * @file sqlplugin.cc
 * @brief Daemon plugin.
 *
 * The plugin is used to initialize those function that use mutexes for
 * static storage.
 */

#include <stdio.h>
#include "config.h"
#include "sqlstat.h"
#include "sqlplugin.h"
#include "sqlrand.h"

using sqlstat::MersenneTwister;

static int plugin_is_loaded = 0;

/**
 * \fn int sqlstat_plugin_init(void *p)
 * @brief Initializes plugin.
 *
 */
int sqlstat_plugin_init(void *p) {
  fprintf(stderr, "Statistics for MySQL %s: "
          "plugin loaded.\n", VERSION);
  MersenneTwister::init();
  plugin_is_loaded = 1;
  return 0;
}

/**
 * \fn int sqlstat_plugin_deinit(void *p)
 * @brief Deinitializes plugin.
 *
 */
int sqlstat_plugin_deinit(void *p) {
  fprintf(stderr, "Statistics for MySQL %s: "
          "plugin unloaded.\n", VERSION);
  MersenneTwister::deinit();
  plugin_is_loaded = 0;
  return 0;
}

/**
 * \fn int int sqlstat_plugin_isloaded()
 * @brief Check if plugin loaded.
 * @return plugin loaded = 1, plugin not loaded = 0
 */
int sqlstat_plugin_isloaded() {
  return plugin_is_loaded;
  }
