/* testrownumber.c (Row number) */

/***********************************************************************
*  This code is part of Statistics for MySQL.
*
*  Copyright (C) 2011 Heinrich Schuchardt (xypron.glpk@gmx.de)
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
***********************************************************************/

/**
 * @file testrownumber.c
 * @brief Test row number function.
 */
 
#include <stdlib.h>
#include <stdio.h>
#include "sqlstat.h"

/**
 * \fn int main(int argc, char *argv[])
 * @brief Main
 * @param argc number of arguments
 * @param argv arguments
 * @return success = EXIT_SUCCESS = 0
 */
int main(int argc, char *argv[]) {
  enum Item_result arg_type[1];
  long long *p_args[1];
  long long x;
  
  UDF_INIT initid;
  UDF_ARGS udf_args;
  char error;
  char is_null;
  char message[MYSQL_ERRMSG_SIZE] = "\0";
  my_bool ret;
  
  int i;
  long long actual;
  long long expected;

  printf ("Running test: %s\n", __FILE__);
 
  udf_args.arg_type = arg_type;
  p_args[0] = &x;
  udf_args.args = (char **) p_args;

  /* Test init */
  udf_args.arg_count = 1;
  ret = rownumber_init(&initid, &udf_args, message);
  if (ret == 0 ) {
    printf ("Number of arguments not checked\n");
    return EXIT_FAILURE;
  }

  /* Init */
  udf_args.arg_count = 0;
  ret = rownumber_init(&initid, &udf_args, message);
  if (ret != 0 ) {
    printf ("Unexpexted error\n");
    return EXIT_FAILURE;
  }
  
  expected = 0;
  for (i = 0; i < 100; i++) {
    actual = rownumber(&initid, &udf_args, &is_null, &error);
    expected++;
    if (actual != expected) {
      printf("Expected value: %lld\nActual value: %lld\n", expected, actual);
      return EXIT_FAILURE;
    }  
  }

  /* Deinit */
  rownumber_deinit(&initid);

  /* Init */
  udf_args.arg_count = 0;
  ret = rownumber_init(&initid, &udf_args, message);
  if (ret != 0 ) {
    printf ("Unexpexted error\n");
    return EXIT_FAILURE;
  }
  
  expected = 0;
  for (i = 0; i < 100; i++) {
    actual = rownumber(&initid, &udf_args, &is_null, &error);
    expected++;
    if (actual != expected) {
      printf("Expected value: %lld\nActual value: %lld\n", expected, actual);
      return EXIT_FAILURE;
    }  
  }

  /* Deinit */
  rownumber_deinit(&initid);
  
  printf("Test passed successfully: %s\n", __FILE__);
  
  return EXIT_SUCCESS;
}
