/* testmedian.c (median) */

/***********************************************************************
*  This code is part of Statistics for MySQL.
*
*  Copyright (C) 2011 Heinrich Schuchardt (xypron.glpk@gmx.de)
*
*  Licensed under the Apache License, Version 2.0 (the "License");
*  you may not use this file except in compliance with the License.
*  You may obtain a copy of the License at
*
*      http://www.apache.org/licenses/LICENSE-2.0
*
*  Unless required by applicable law or agreed to in writing, software
*  distributed under the License is distributed on an "AS IS" BASIS,
*  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
*  See the License for the specific language governing permissions and
*  limitations under the License.
***********************************************************************/

#include <stdlib.h>
#include <stdio.h>
#include "sqlstat.h"

struct pair {
  double x;
  double y;
};

int main(int argc, char *argv[]) {

  enum Item_result arg_type[1];
  double *p_args[1];
  
  UDF_INIT initid;
  UDF_ARGS udf_args;
  char error;
  char is_null;
  char message[MYSQL_ERRMSG_SIZE] = "\0";
  my_bool ret;
  
  int n;
  double x;
  double expected;
  double actual;

  printf ("Running test: %s\n", __FILE__);
  
  udf_args.arg_type = arg_type;
  p_args[0] = &x;
  udf_args.args = (char **) p_args;

  /* Test init */
  udf_args.arg_count = 0;
  ret = skewness_samp_init(&initid, &udf_args, message);
  if (ret == 0 ) {
    printf ("Number of arguments not checked\n");
    return EXIT_FAILURE;
  }

  /* Init */
  udf_args.arg_count = 1;
  ret = skewness_samp_init(&initid, &udf_args, message);
  if (ret != 0 ) {
    printf ("Unexpexted error\n");
    return EXIT_FAILURE;
  }

  if (arg_type[0] !=  REAL_RESULT) {
    printf ("Wrong argument type for argument 1\n");
    return EXIT_FAILURE;
  }

  /* Test data set 1 */
  skewness_samp_clear(&initid, &is_null, &error);

  x = 0;
  skewness_samp_add(&initid, &udf_args, &is_null, &error);
  x = 1;
  skewness_samp_add(&initid, &udf_args, &is_null, &error);
  x = 2;
  skewness_samp_add(&initid, &udf_args, &is_null, &error);
  actual = skewness_samp(&initid, &udf_args, &is_null, &error);
  expected = 0;
  
  if (fabs(actual - expected) >= 1E-7) {
    printf("Expected value: %f\nActual value: %f\n", expected, actual);
    return EXIT_FAILURE;
  }

  /* Test data set 2 */
  skewness_samp_clear(&initid, &is_null, &error);

  x = 61;
  for (n = 5; n > 0; n--) {
    skewness_samp_add(&initid, &udf_args, &is_null, &error);
  }
  x = 64;
  for (n = 18; n > 0; n--) {
    skewness_samp_add(&initid, &udf_args, &is_null, &error);
  }
  x = 67;
  for (n = 42; n > 0; n--) {
    skewness_samp_add(&initid, &udf_args, &is_null, &error);
  }
  x = 70;
  for (n = 27; n > 0; n--) {
    skewness_samp_add(&initid, &udf_args, &is_null, &error);
  }
  x = 73;
  for (n = 8; n > 0; n--) {
    skewness_samp_add(&initid, &udf_args, &is_null, &error);
  }

  actual = skewness_samp(&initid, &udf_args, &is_null, &error);
  expected = -0.1098084087109530;
  
  if (fabs(actual - expected) >= 1E-7) {
    printf("Expected value: %f\nActual value: %f\n", expected, actual);
    return EXIT_FAILURE;
  }

  /* Test data set 3 */
  skewness_samp_clear(&initid, &is_null, &error);

  actual = skewness_samp(&initid, &udf_args, &is_null, &error);
  if (is_null != 1) {
    printf("Expected NULL\n");
    return EXIT_FAILURE;
  }
  
  /* Deinit */
  skewness_samp_deinit(&initid);
  
  printf("Test passed successfully: %s\n", __FILE__);

  return EXIT_SUCCESS;
}
